==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebNavDrawerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerDescription } from "./WebNavDrawerDescription";
/**
 * @hidden
 */
export let WebNavDrawerDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNavDrawerDescriptionMetadata extends Base {
        static b(a) {
            if (WebNavDrawerDescriptionMetadata.a == null) {
                WebNavDrawerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNavDrawerDescriptionMetadata.c(WebNavDrawerDescriptionMetadata.a);
            }
            if (a.k(WebNavDrawerDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebNavDrawerDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:NavDrawer");
            a.item("__tagNameWC", "String:igc-nav-drawer");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Position", "ExportedType:string:NavDrawerPosition");
            a.item("Position@stringUnion", "WebComponents;React");
            a.item("Position@names", "Top;Bottom;Start;End;Relative");
            a.item("Open", "Boolean");
        }
        static d(a) {
            WebNavDrawerDescriptionMetadata.b(a);
            a.ad("WebNavDrawer", () => new WebNavDrawerDescription());
            a.ac("WebNavDrawer", WebNavDrawerDescriptionMetadata.a);
        }
    }
    WebNavDrawerDescriptionMetadata.$t = /*@__PURE__*/ markType(WebNavDrawerDescriptionMetadata, 'WebNavDrawerDescriptionMetadata');
    WebNavDrawerDescriptionMetadata.a = null;
    return WebNavDrawerDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebNavDrawerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerDescription } from "./WebNavDrawerDescription";
/**
 * @hidden
 */
export let WebNavDrawerDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNavDrawerDescriptionMetadata extends Base {
        static b(a) {
            if (WebNavDrawerDescriptionMetadata.a == null) {
                WebNavDrawerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNavDrawerDescriptionMetadata.c(WebNavDrawerDescriptionMetadata.a);
            }
            if (a.k(WebNavDrawerDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebNavDrawerDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:NavDrawer");
            a.item("__tagNameWC", "String:igc-nav-drawer");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Position", "ExportedType:string:NavDrawerPosition");
            a.item("Position@stringUnion", "WebComponents;React");
            a.item("Position@names", "Start;End;Bottom;Top;Relative");
            a.item("Open", "Boolean");
        }
        static d(a) {
            WebNavDrawerDescriptionMetadata.b(a);
            a.ae("WebNavDrawer", () => new WebNavDrawerDescription());
            a.ad("WebNavDrawer", WebNavDrawerDescriptionMetadata.a);
        }
    }
    WebNavDrawerDescriptionMetadata.$t = /*@__PURE__*/ markType(WebNavDrawerDescriptionMetadata, 'WebNavDrawerDescriptionMetadata');
    WebNavDrawerDescriptionMetadata.a = null;
    return WebNavDrawerDescriptionMetadata;
})();
